var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
import { commonsTypeIsNumberKeyObject, commonsTypeIsString, commonsTypeIsTArray } from 'tscommons-es-core';
import { CommonsRestClientService } from 'tscommons-es-rest';
import { isIUomLibraryPollsOption } from '../interfaces/iuom-library-polls-option';
import { isTUomLibraryPollsOption } from '../types/tuom-library-polls-option';
import { isTUomLibraryPollsPoll } from '../types/tuom-library-polls-poll';
import { decodeIUomLibraryPollsPoll } from '../types/tuom-library-polls-poll';
import { decodeIUomLibraryPollsOption } from '../types/tuom-library-polls-option';
export class UomLibraryPollsRestClientService extends CommonsRestClientService {
    listByNamespace(namespace, options = {}) {
        return __awaiter(this, void 0, void 0, function* () {
            const polls = yield this.getRest(`/polls/namespaces/${namespace}`, undefined, undefined, options);
            if (!commonsTypeIsTArray(polls, isTUomLibraryPollsPoll))
                throw new Error('Invalid result for polls');
            return polls
                .map((poll) => decodeIUomLibraryPollsPoll(poll));
        });
    }
    listOptionsByPoll(poll, options = {}) {
        return __awaiter(this, void 0, void 0, function* () {
            const data = yield this.getRest(`/polls/${poll.uid}/options`, undefined, undefined, options);
            if (!commonsTypeIsTArray(data, isTUomLibraryPollsOption))
                throw new Error('Invalid result for options');
            return data
                .map((option) => decodeIUomLibraryPollsOption(option));
        });
    }
    getResults(poll, options = {}) {
        return __awaiter(this, void 0, void 0, function* () {
            const results = yield this.getRest(`/polls/${poll.uid}/results`, undefined, undefined, options);
            if (!commonsTypeIsNumberKeyObject(results))
                throw new Error('Invalid results for poll');
            return results;
        });
    }
    vote(poll, votes, options = {}) {
        return __awaiter(this, void 0, void 0, function* () {
            const uids = [];
            if (poll.multi) {
                if (!commonsTypeIsTArray(votes, isIUomLibraryPollsOption))
                    throw new Error('Invalid multiple votes');
                uids.push(...votes
                    .map((vote) => vote.uid));
            }
            else {
                if (!isIUomLibraryPollsOption(votes))
                    throw new Error('Invalid single vote');
                uids.push(votes.uid);
            }
            const response = yield this.postRest(`/polls/${poll.uid}/responses/${uids.join(',')}`, {}, undefined, undefined, options);
            if (!commonsTypeIsString(response))
                throw new Error('Invalid response uid for vote');
            return response;
        });
    }
}
//# sourceMappingURL=uom-library-polls-rest-client.service.js.map